@@ -19,6 +19,7 @@
 
 #include <stdlib.h>
 #include <stdio.h>
+#include <stdarg.h>
 
 #ifdef HAVE_STRING_H
 # include <string.h>
@@ -29,10 +30,20 @@
 #include "wrappers.h"
 
 extern void
-die (msg)
-     char *msg;
+die (const char *msg, ...)
 {
-  fprintf (stderr, "motti: %s\n", msg);
+  va_list args;
+  char *fullmsg;
+  int len;
+  va_start (args, msg);
+
+  len = strlen (msg)+1;
+  fullmsg = my_malloc (len * sizeof (char));
+
+  sprintf (fullmsg, "motti: %s\n", msg);
+  vfprintf (stderr, fullmsg, args);
+  va_end (args);
+  free (fullmsg);
   exit (1);
 }
 
@@ -74,7 +85,11 @@ my_malloc (size)
   void *ptr;
   ptr = malloc(size);
   if (ptr == NULL && size != 0)
-    die (alloc_err_str (ERR_MALLOC, ""));
+    {
+      /* Function die uses my_malloc, so we can't use it here.  */
+      fprintf (stderr, "motti: malloc error\n");
+      exit (1);
+    }
   return ptr;
 }
 
@@ -85,6 +100,10 @@ my_calloc (nmemb, size)
   void *ptr;
   ptr = calloc (nmemb, size);
   if (ptr == NULL && size != 0)
-    die (alloc_err_str (ERR_MALLOC, ""));
+    {
+      /* Function die uses my_malloc, so we can't use it here.  */
+      fprintf (stderr, "motti: calloc error\n");
+      exit (1);
+    }
   return ptr;
 }
